translate.storage.placeables.base

Package translate :: Package storage :: Package placeables :: Module base |
[hide private]
[frames] | no frames]

# Module base

source code

Contains base placeable classes with names based on XLIFF placeables. See the XLIFF standard for more information about what the names mean.

Classes | [hide private]
| Bpt
| Ept
| Ph
| It
| G
| Bx
| Ex
| X
| Sub

Functions | [hide private]
to_base_placeables(tree) | source code

Imports: InvisiblePlaceable, SubflowPlaceable, StringElem, PairedDelimiter, Delimiter, MaskingPlaceable, ReplacementPlaceable